pub struct FileLine {
pub content: String,
pub coverage_status: String,
pub line_number: i64,
pub test_types: Option<Vec<String>>,
}Expand description
Represents a single line of code with coverage information.
JSON schema
{
"title": "FileLine",
"description": "Represents a single line of code with coverage information.",
"type": "object",
"required": [
"content",
"coverage_status",
"line_number"
],
"properties": {
"content": {
"title": "Content",
"type": "string"
},
"coverage_status": {
"title": "Coverage Status",
"type": "string"
},
"line_number": {
"title": "Line Number",
"type": "integer"
},
"test_types": {
"title": "Test Types",
"type": [
"array",
"null"
],
"items": {
"type": "string"
}
}
}
}Fields
content: Stringcoverage_status: Stringline_number: i64test_types: Option<Vec<String>>Implementations