pub struct FileNode {
pub children: Option<Vec<FileNode>>,
pub coverage: Option<f64>,
pub expanded: Option<bool>,
pub name: String,
pub path: String,
pub type_: String,
}Expand description
Represents a file or folder in the repository tree.
JSON schema
{
"title": "FileNode",
"description": "Represents a file or folder in the repository tree.",
"type": "object",
"required": [
"name",
"path",
"type"
],
"properties": {
"children": {
"title": "Children",
"type": [
"array",
"null"
],
"items": {
"$ref": "#/components/schemas/FileNode"
}
},
"coverage": {
"title": "Coverage",
"type": [
"number",
"null"
]
},
"expanded": {
"title": "Expanded",
"type": [
"boolean",
"null"
]
},
"name": {
"title": "Name",
"type": "string"
},
"path": {
"title": "Path",
"type": "string"
},
"type": {
"title": "Type",
"type": "string"
}
}
}Fields
children: Option<Vec<FileNode>>coverage: Option<f64>expanded: Option<bool>name: Stringpath: Stringtype_: StringImplementations