ProfilingSessionCreate

Struct ProfilingSessionCreate 

pub struct ProfilingSessionCreate {
    pub environment: Option<String>,
    pub language: Language,
    pub metadata: Option<Map<String, Value>>,
    pub name: Option<String>,
    pub session_id: String,
    pub traces: Vec<ProfilingTrace>,
    pub version: Option<String>,
}
Request to create a new profiling session with traces.

JSON schema
{
 "title": "ProfilingSessionCreate",
 "description": "Request to create a new profiling session with traces.",
 "type": "object",
 "required": [
   "language",
   "session_id",
   "traces"
 ],
 "properties": {
   "environment": {
     "title": "Environment",
     "description": "Environment (dev, staging, production)",
     "type": [
       "string",
       "null"
     ]
   },
   "language": {
     "title": "Language",
     "description": "Programming language",
     "type": "string",
     "enum": [
       "python",
       "java",
       "go",
       "typescript",
       "javascript",
       "ruby",
       "rust",
       "c++",
       "c#",
       "php"
     ]
   },
   "metadata": {
     "title": "Metadata",
     "description": "Additional session metadata",
     "type": [
       "object",
       "null"
     ],
     "additionalProperties": true
   },
   "name": {
     "title": "Name",
     "description": "Human-readable name for the session",
     "type": [
       "string",
       "null"
     ]
   },
   "session_id": {
     "title": "Session Id",
     "description": "Unique identifier for this profiling session",
     "type": "string"
   },
   "traces": {
     "title": "Traces",
     "description": "List of profiling traces",
     "type": "array",
     "items": {
       "$ref": "#/components/schemas/ProfilingTrace"
     },
     "minItems": 1
   },
   "version": {
     "title": "Version",
     "description": "Application/library version",
     "type": [
       "string",
       "null"
     ]
   }
 }
}

Fields

environment: Option<String>

Environment (dev, staging, production)

language: Language

Programming language

metadata: Option<Map<String, Value>>

Additional session metadata

name: Option<String>

Human-readable name for the session

session_id: String

Unique identifier for this profiling session

traces: Vec<ProfilingTrace>

List of profiling traces

version: Option<String>

Application/library version

Implementations